@@ -9,6 +9,8 @@
 #' @return Invisibly returns the p-value of the test statistics. A p-value < 0.05
 #' indicates a non-constant variance (heteroskedasticity).
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @examples
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_heteroscedasticity(m)
@@ -26,9 +28,8 @@ check_heteroscedasticity <- function(x, ...) {
 
 #' @export
 check_heteroscedasticity.default <- function(x, ...) {
-  sumry <- summary(x)
   r <- stats::residuals(x, type = "pearson")
-  S.sq <- stats::df.residual(x) * (sumry$sigma)^2 / sum(!is.na(r))
+  S.sq <- stats::df.residual(x) * .sigma(x)^2 / sum(!is.na(r))
 
   .U <- (r^2) / S.sq
   mod <- lm(.U ~ stats::fitted(x))
@@ -50,3 +51,12 @@ check_heteroscedasticity.default <- function(x, ...) {
 
   invisible(p.val)
 }
+
+
+
+#' @importFrom insight get_parameters n_obs
+#' @importFrom stats deviance
+.sigma <- function(x) {
+  estimates <- insight::get_parameters(x)$Estimate
+  sqrt(stats::deviance(x) / (insight::n_obs(x) - sum(!is.na(estimates))))
+}
