@@ -12,6 +12,8 @@
       return(NULL)
     }
     VGAM::BIC(x)
+  } else if (inherits(x, "bayesx")) {
+    stats::BIC(x)[["BIC"]]
   } else {
     tryCatch(
       {
@@ -117,6 +119,10 @@
     return(x)
   }
 
+  if (is.logical(x)) {
+    return(as.numeric(x))
+  }
+
   if (anyNA(suppressWarnings(as.numeric(as.character(stats::na.omit(x)))))) {
     if (is.character(x)) {
       x <- as.factor(x)
